﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Steema.TeeChart.Styles;

namespace HistogramTest
{
	public partial class Form1 : Form
	{
		public Form1()
		{
			InitializeComponent();

			tChart1.DoubleClick += new EventHandler(tChart1_DoubleClick);

			Histogram histo = new Histogram();
			
			DateTime dtFirst = DateTime.Now;
			DataTable dt = GetSampleData(ref dtFirst);

			histo.Color = Color.Transparent;
			histo.DataSource = dt;
			histo.XValues.DataMember = "X";
			histo.YValues.DataMember = "Y";

			tChart1.Series.Add(histo);

			if (MessageBox.Show("Add Color.Transparent ?", "Question", MessageBoxButtons.YesNo) == DialogResult.Yes)
			{	// Fault, Safe, Nothing Data...
				for (int i =0; i < dt.Rows.Count; i++)
				{
					if (i % 2 == 0)
						tChart1.Series[0][i].Color = Color.Red;	// Fault
					else if (i%3 == 0)
						tChart1.Series[0][i].Color = Color.Blue; // Safe
					else
					    histo[i].Color = Color.Transparent;	// Nothing...
				}
			}
			else
			{
				for (int i =0; i < dt.Rows.Count; i++)
				{
					if (i % 2 == 0)
						tChart1.Series[0][i].Color = Color.Red;	// Fault
					else 
						tChart1.Series[0][i].Color = Color.Blue; // Safe
				}
			}
		}

		void tChart1_DoubleClick(object sender, EventArgs e)
		{
			tChart1.ShowEditor();
		}

		private DataTable CreateDataTable(string tableName)
		{
			DataTable dt = new DataTable(tableName);

			dt.Columns.Add("xDate", typeof(DateTime));
			dt.Columns.Add("x", typeof(double));
			dt.Columns.Add("y", typeof(double));
			dt.Columns.Add("y2", typeof(double));
			dt.Columns.Add("usl", typeof(double));
			dt.Columns.Add("lsl", typeof(double));
			dt.Columns.Add("eqp_id", typeof(string));
			dt.Columns.Add("lot_id", typeof(string));
			dt.Columns.Add("ppid", typeof(string));
			dt.Columns.Add("desc", typeof(string));
			dt.Columns.Add("fcount", typeof(string));
			dt.Columns.Add("alarm", typeof(int));
			dt.Columns.Add("eqp_id2", typeof(string));
			dt.Columns.Add("param_name", typeof(string));
			dt.Columns.Add("test", typeof(string));

			//SetComboItemOfLabelColumn(dt.Columns);

			return dt;
		}

		private DataTable GetSampleData(ref DateTime dtFirst)
		{
			string tableName = "test";// GetSeriesName();
			int sampleCount = 100;// GetSampleCount();

			DataTable dt = CreateDataTable(tableName);
			Random ran = new Random(DateTime.Now.Second);

			double usl = 0;
			double lsl = 0;

			int fromValue = -20;// Convert.ToInt32(txtFrom.Text);
			int toValue = 20;// Convert.ToInt32(txtTo.Text);

			double oldY = Double.NaN; ;
			for (int i = 0; i < sampleCount; i++)
			{
				double x = i;
				double y = 0;

				if (Double.IsNaN(oldY) || Math.Abs(oldY) <= 4)
					y = ran.Next(fromValue, toValue);
				else
				{
					int old = (int)Math.Round(oldY);
					int baseY =  Math.Abs(old * 20 / 100);
					y = ran.Next(old - baseY, old + baseY);
					if (y == 4)
					{
					}
				}
				oldY = y;

				if (usl < y) usl = y;
				if (lsl > y) lsl = y;

				DateTime dtDate = dtFirst;

				DataRow drNew = dt.NewRow();
				drNew["xDate"] = dtDate;
				drNew["x"] = x;
				drNew["y"] = y + t4 * i;
				drNew["y2"] = y - 10;
				if (y % 3 == 0)
				{
					drNew["usl"] = usl;
					drNew["lsl"] = lsl;
				}
				int intY = (int)Math.Round(y, 0);
				drNew["eqp_id"] = intY % 2 == 0 ? Environment.MachineName : "Dummy";
				drNew["lot_id"] = "lotid." + (intY % 3);
				drNew["eqp_id2"] = String.Format("EQP{0}", i.ToString().PadLeft(2, '0'));
				drNew["param_name"] = String.Format("Param - {0}", tableName);

				dt.Rows.Add(drNew);
			}

			//this.SetMergeInfo();

			return dt;
		}
		double t4 = 0.2834567;
	}
}
